#
# spec file for package cdemu-daemon
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


#Compat macro for new _fillupdir macro introduced in Nov 2017
%if ! %{defined _fillupdir}
  %define _fillupdir /var/adm/fillup-templates
%endif

Name:           cdemu-daemon
Version:        3.1.0
Release:        61.4
Summary:        Device daemon for cdemu, a virtual CD-ROM device emulator
License:        GPL-2.0-or-later
Group:          System/Daemons
Url:            http://cdemu.sf.net/about/daemon/

#Git-Clone:	git://git.code.sf.net/p/cdemu/code
Source:         http://downloads.sf.net/cdemu/%name-%version.tar.bz2
Source2:        60-vhba.rules
Source3:        cdemu-daemon.sysconfig
Patch1:         logfile.diff
BuildRequires:  cmake >= 2.8.5
BuildRequires:  intltool >= 0.21
BuildRequires:  pkg-config >= 0.16
BuildRequires:  pkgconfig(ao) >= 0.8.0
BuildRequires:  pkgconfig(gio-2.0) >= 2.28
BuildRequires:  pkgconfig(glib-2.0) >= 2.28
BuildRequires:  pkgconfig(gmodule-2.0) >= 2.28
BuildRequires:  pkgconfig(gobject-2.0) >= 2.28
BuildRequires:  pkgconfig(gthread-2.0) >= 2.28
BuildRequires:  pkgconfig(libmirage) >= %version
Requires(pre):  %fillup_prereq
Requires:       vhba-kmp
Recommends:     %name-lang

%lang_package

%description
cdemu-daemon receives SCSI commands from kernel module thorugh the
VHBA module and processes them, passing the requested data back to
the kernel. The daemon implements the actual virtual device; one
instance per each device registered by kernel module. It uses
libmirage for the image access (e.g. sector reading).

The daemon registers itself on D-BUS's system or session bus
(depending on the options passed to it) where it exposes an interface
that can be used by clients to control it.

%prep
%setup -q
%patch -P 1 -p1

%build
%cmake -DCMAKE_INSTALL_LIBEXECDIR:PATH="%_libexecdir"
make %{?_smp_mflags}

%install
b="%buildroot"
%cmake_install
mkdir -p "$b/%_sbindir" "$b/%{_fillupdir}" \
	"$b/%_prefix/lib/udev/rules.d"
install -pm0644 "%{S:2}" "$b/%_prefix/lib/udev/rules.d/60-vhba.rules"
install -pm0644 "%{S:3}" "$b/%{_fillupdir}/sysconfig.cdemu-daemon"
# Not desired for security; it would permit a user to start a system service.
rm -rf "$b/%_datadir/dbus-1/system-services" "$b/%_sysconfdir/dbus-1/system.d/"
%find_lang %name

%post
%fillup_only

%files -f %name.lang
%defattr(-,root,root)
%doc AUTHORS COPYING README
%_bindir/cdemu-daemon
%_libexecdir/cdemu-daemon-session.sh
%_datadir/dbus-1/
%_mandir/man8/cdemu-daemon.8*
%{_fillupdir}/sysconfig.cdemu-daemon
%_prefix/lib/udev/

%changelog
* Wed Apr 25 2018 p.seiler@linuxmail.org
- Changed vhba-kmp package from recommend to require for /dev/vhba_ctl
  * cdemu is not working if vhba kernel module is not installed
* Thu Nov 23 2017 rbrown@suse.com
- Replace references to /var/adm/fillup-templates with new
  %%_fillupdir macro (boo#1069468)
* Mon Aug  7 2017 jengelh@inai.de
- Update to new upstream release 3.1.0
  * Added no-op implementation of RESERVE TRACK for all
    recording modes.
  * Added infrastructure for localization support.
  * Added Slovenian and Russian translations.
* Mon Feb  6 2017 jengelh@inai.de
- Update to new upstream release 3.0.5
  * Only updates for other distros
- New udev rules using the "uaccess" method
* Fri Jan 22 2016 jengelh@inai.de
- Update to new upstream release 3.0.4
  * Ensure "disc_closed" variable is set accordingly
* Mon Jan  4 2016 jengelh@inai.de
- Recommend vhba-kmp package for /dev/vhba_ctl [boo#960464]
* Mon Nov 23 2015 jengelh@inai.de
- Update to new upstream release 3.0.3
  * fixed a copy-and-paste error in feature initialization code
  * daemon: device: signal the Media Eject Request event only when
  device unload is requested via D-Bus API
- Run %%fillup and populate /etc/sysconfig/cdemu-daemon
- Drop cdemu_daemon_typo_in_mmc_packet_commands_h.patch (merged)
* Thu Feb 26 2015 normand@linux.vnet.ibm.com
- new cdemu_daemon_typo_in_mmc_packet_commands_h.patch
  to avoid ppc/ppc64 build failure
  related to upstream ticket https://sourceforge.net/p/cdemu/patches/22/
* Thu Oct  2 2014 jengelh@inai.de
- Update to new upstream release 3.0.2
  * properly report last session lead-in address as 0xFFFFFFFF on
  closed and non-recordable discs. Fixes "Used capacity" in K3B's
  Medium Information right after writing an image to the virtual
  disc.
  * fixed a typo that prevented CD-TEXT being recorded on any
  recording attempt beyond the first one
* Mon Sep 22 2014 jengelh@inai.de
- Request matching libmirage version for build
* Sun Jul 13 2014 sor.alexei@meowr.ru
- Update to new upstream release 3.0.0
  * The CDEmu daemon now has experimental emulation of CD-R and
  DVD+R disc recording, and daemon/client protocol was extended
  to allow transmission of image writer parameters descriptions
  from daemon to client and parameters' values back from client
  to daemon.
- Remove logfile.diff patch
- Add /dev/vhba_ctl read-write access udev rule
* Sun Nov 24 2013 jengelh@inai.de
- Update to new upstream release 2.1.1
  * allow bad sector verification to be turned off (which is now
  default) in order to increase device throughput
  * DPM emulation is now turned off by default as well
  * make sure that EDC and subchannel verification is never performed
  for generated data
* Sun Jun  9 2013 jengelh@inai.de
- Update to new upstream release 2.1.0
  * Use non-blocking I/O on VHBA control device, implemented device
  restart on kernel/userspace I/O errors
  * Added support for device addition/removal. To preserve device
  numbering, devices can only be appended, and only the last device
  can be removed.
  * Auto-started daemon now creates only a single device by default.
  * Fixed device ID reported by INQUIRY, where last letters were
  missing
  * Session autostart script now uses "default" instead of "pulse"
  for audio driver.
  * If audio device initialization fails, fallback to "null" instead
  of just stopping the playback thread.
* Sat Apr 13 2013 jengelh@inai.de
- Resolve build failure with glib 2.36 by allowing deprecated
  functions for the time being (-UG_DISABLE_DEPRECATED)
* Sat Dec 22 2012 jengelh@inai.de
- Update to new upstream release 2.0.0 (up from 1.5.0)
  * Support for ISZ, CSO, DMG, GBI, ECM, gzip and xz formats
  * Partial support for 1-track MDX
- Resolves a problem with autostarting cdemu-daemon
  (bnc#809181, bnc#809862)
* Mon Nov 19 2012 jengelh@inai.de
- Remove cdemud-launch helper, this caused too much confusion.
* Tue May 29 2012 jengelh@inai.de
- Remove dbus autostart and systemd unit file for system-bus mode.
  Place system logfile in proper place (bnc#764063)
* Tue May  8 2012 jengelh@inai.de
- Initial package for build.opensuse.org
